@@ -4,9 +4,6 @@ import json
 
 HONKAIDEX_DATA = os.path.dirname(os.path.realpath(__file__))
 
-HONKAI_FANDOM = "https://honkaiimpact3.fandom.com"
-HONKAI_FANDOM_STIGAMATA = "https://honkaiimpact3.fandom.com/wiki/Stigmata"
-
 __LOADED_TRACK__ = {}
 
 def load_once():
