@@ -19,7 +19,7 @@ def load():
         character_data : dict
         character = BaseCharacter.create(
             name=character_data["name"],
-            nicknames=character_data.get("nicknames", []),
+            nickname=character_data.get("nickname", []),
         )
 
 
@@ -33,4 +33,5 @@ def load():
                 rarity=bs_data["rank"],
                 tags=bs_data.get("tags", []),
                 img_link=bs_data.get("img_link", None),
+                nickname=bs_data["nickname"]
             )
